==> scantailor_0.9.6.orig.tar.gz: scantailor-0.9.6/translations/crashreporter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="62"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation>Этот файл содержит внутреннее состояние программы на момент падения</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="68"/>
        <source>Dump file</source>
        <translation>Файл дампа</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="98"/>
        <source>Sending ...</source>
        <translation>Отправка ...</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="126"/>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="149"/>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="207"/>
        <source>Sending failed</source>
        <translation>Отправить не удалось</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="212"/>
        <source>Successfully sent</source>
        <translation>Успешно отправлено</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation>Сообщение о падении</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix this problem by submitting this crash report.</source>
        <translation>Scan Tailor упал.  Обычно это результат ошибок в программе.  Вы можете помочь нам найти и исправить эту проблему, отправив этот отчет о падении.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation>Информация, которая будет отправлена</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation>Если у вас есть дополнительная информация, например если вы знаете, как воспроизвести падение - пишите ее сюда.
Писать можно по-русски или по-английски.</translation>
    </message>
    <message>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.</source>
        <translation type="obsolete">Если у вас есть дополнительная информация, например если вы знаете, как воспроизвести падение - пишите ее сюда.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation>Если вы согласны оказать дополнительное содействие разработчикам в поиске этой проблемы, укажите свой адрес электронной почты.</translation>
    </message>
    <message>
        <source>If you are willing to provide further assistance to developers to help fix this problem, plese provide your email address.</source>
        <translation type="obsolete">Если вы согласны оказать дополнительное содействие разработчикам в поиске этой проблемы, укажите свой адрес электронной почты.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation>Email [не обязательно]</translation>
    </message>
</context>
</TS>

==> scantailor_0.9.7.2.orig.tar.gz: scantailor-0.9.7.2/translations/crashreporter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="70"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation>Этот файл содержит внутреннее состояние программы на момент падения</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="76"/>
        <source>Dump file</source>
        <translation>Файл дампа</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="104"/>
        <source>Sending ...</source>
        <translation>Отправка ...</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="135"/>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation>Неожиданный ответ (код %1) распределителя</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="160"/>
        <source>Unexpected response from dispatcher</source>
        <translation>Неожиданный ответ распределителя</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="220"/>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation>Неожиданный ответ (код %1) от принимающей стороны</translation>
    </message>
    <message>
        <source>Sending failed</source>
        <translation type="obsolete">Отправить не удалось</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="226"/>
        <source>Successfully sent</source>
        <translation>Успешно отправлено</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation>Сообщение о падении</translation>
    </message>
    <message>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix this problem by submitting this crash report.</source>
        <translation type="obsolete">Scan Tailor упал.  Обычно это результат ошибок в программе.  Вы можете помочь нам найти и исправить эту проблему, отправив этот отчет о падении.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation>Scan Tailor упал.  Обычно это результат ошибок в программе.  Вы можете помочь нам найти и исправить эту проблему, отправив этот отчет о падении.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation>Информация, которая будет отправлена</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation>Если у вас есть дополнительная информация, например если вы знаете, как воспроизвести падение - пишите ее сюда.
Писать можно по-русски или по-английски.</translation>
    </message>
    <message>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.</source>
        <translation type="obsolete">Если у вас есть дополнительная информация, например если вы знаете, как воспроизвести падение - пишите ее сюда.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation>Если вы согласны оказать дополнительное содействие разработчикам в поиске этой проблемы, укажите свой адрес электронной почты.</translation>
    </message>
    <message>
        <source>If you are willing to provide further assistance to developers to help fix this problem, plese provide your email address.</source>
        <translation type="obsolete">Если вы согласны оказать дополнительное содействие разработчикам в поиске этой проблемы, укажите свой адрес электронной почты.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation>Email [не обязательно]</translation>
    </message>
</context>
</TS>
